{% load admin_static admin_list static i18n %}
<table>
    <thead>
        <tr>
            <th><div class="text">{% trans "Name" %}</div></th>
            <th><div class="text">{% trans "Default" %}</div></th>
            <th><div class="text">{% trans "Value" %}</div></th>
            <th><div class="text">{% trans "Is modified" %}</div></th>
        </tr>
    </thead>
    {% for item in config_values %}
    <tr class="{% cycle 'row1' 'row2' %}">
        <th>
            {{ item.name }} <div class="help">{{ item.help_text|linebreaksbr }}</div>
        </th>
        <td>
            {{ item.default|linebreaks }}
        </td>
        <td>
            {{ item.form_field.errors }}
            {% if item.is_file %}{% trans "Current file" %}: <a href="{% get_media_prefix as MEDIA_URL %}{{ MEDIA_URL }}{{ item.value }}" target="_blank">{{ item.value }}</a>{% endif %}
            {{ item.form_field }}
            <br>
            <a href="#" class="reset-link"
                data-field-id="{{ item.form_field.auto_id }}"
                data-field-type="{% spaceless %}
                {% if item.is_checkbox %}checkbox
                {% elif item.is_date %}date
                {% elif item.is_datetime %}datetime
                {% endif %}
                {% endspaceless %}"
                data-default="{% spaceless %}
                {% if item.is_checkbox %}{% if item.raw_default %} true {% else %} false {% endif %}
                {% elif item.is_date %}{{ item.raw_default|date:"U" }}
                {% elif item.is_datetime %}{{ item.raw_default|date:"U" }}
                {% else %}{{ item.default }}
                {% endif %}
                {% endspaceless %}">{% trans "Reset to default" %}</a>
        </td>
        <td>
            {% if item.modified %}
                <img src="{% static 'admin/img/icon-yes.'|add:icon_type %}" alt="{{ item.modified }}" />
            {% else %}
                <img src="{% static 'admin/img/icon-no.'|add:icon_type %}" alt="{{ item.modified }}" />
            {% endif %}
        </td>
    </tr>
    {% endfor %}
</table>
