#result_list .changed {
    background-color: #ffc;
}
#changelist table thead th .text {
    padding: 2px 5px;
}
#changelist table tbody td:first-child {
    text-align: left;
}
#changelist-form ul.errorlist {
    margin: 0 !important;
}
.help {
    font-weight: normal !important;
}
